<?php

/**
 * Implementation of themehook_settings().
 */
function happypixels_settings($saved_settings) {
  $defaults = array(
    'happypixels_hide_title_background' => FALSE,
    'happypixels_use_custom_header' => FALSE,
  );
  
  $settings = array_merge($defaults, $saved_settings);

  $form['happypixels_use_custom_header'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use a custom header'),
    '#default_value' => $settings['happypixels_use_custom_header'],
  );

  $form['happypixels_custom_header'] = array(
    '#type' => 'file', 
    '#title' => t('Custom header image'),
    '#description' => t('For best quality, upload an image measuring 840x200 pixels.'),
  );
  
  // We add our own submit button to be able to have a custom submit handler.
  $form['happypixels_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Upload the new image'),
    '#submit' => array('happypixels_settings_submit', 'system_theme_settings_submit'),
  );
  if (module_exists('color')) {
    $form['happypixels_submit']['#submit'][] = 'color_scheme_form_submit';
  }
  
  $form['happypixels_hide_title_background'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide the white tab behind the site title and logo.'),
    '#default_value' => $settings['happypixels_hide_title_background'],
  );
  
  $form['happypixels_light_background_gradient'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use a white gradient for the background.'),
    '#default_value' => $settings['happypixels_light_background_gradient'],
  );

  return $form;
}

function happypixels_settings_validate(&$form, $form_state) {
  $file = file_save_upload('happypixels_custom_header', array('file_validate_is_image' => array()));
  
  if ($form_state['values']['happypixels_use_custom_header'] && !variable_set('happypixels_custom_header_available', FALSE)) {
    form_set_error('happypixels_use_custom_header', t('You need to upload a header image first.'));
  }
}

function happypixels_settings_submit(&$form, &$form_state) {
  if ($file = file_save_upload('happypixels_custom_header', array('file_validate_is_image' => array()))) {
    $destination = file_directory_path() . '/happypixels';
    file_check_directory($destination, FILE_CREATE_DIRECTORY);
    $filepath = $destination . '/custom-header.jpg';
    
    if (image_scale_and_crop($file->filepath, $filepath, 840, 200) || file_copy($file, $filepath, FILE_EXISTS_REPLACE)) {
      variable_set('happypixels_custom_header_available', TRUE);
      
      // Automatically check the corresponding checkbox.
      $form_state['values']['happypixels_use_custom_header'] = TRUE;
      
      drupal_set_message(t('Your image has been uploaded. Please check '));
    }
  }
  
  unset($form_state['happypixels_submit']);
}